@@ -1,5 +1,4 @@
 # SNMP::Info::CiscoPortSecurity
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,15 +30,16 @@
 package SNMP::Info::CiscoPortSecurity;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::CiscoPortSecurity::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::CiscoPortSecurity::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE %PAECAPABILITIES/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE, %PAECAPABILITIES);
 
-$VERSION = '3.61';
+$VERSION = '3.81';
 
 %MIBS = (
     'CISCO-PORT-SECURITY-MIB' => 'ciscoPortSecurityMIB',
@@ -110,7 +110,7 @@ $VERSION = '3.61';
 
 %PAECAPABILITIES = (
     0 => 'dot1xPaePortAuthCapable',
-    1 => 'dot1xPaePortSuppCapable'
+    1 => 'dot1xPaePortSuppCapable',
 );
 
 sub munge_pae_capabilities {
@@ -152,14 +152,14 @@ Eric Miller
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $cps = new SNMP::Info(
                         AutoSpecify => 1,
                         Debug       => 1,
                         DestHost    => 'myswitch',
                         Community   => 'public',
                         Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $cps->class();
@@ -196,10 +196,6 @@ None.
 
 These are methods that return scalar values from SNMP
 
-=over
-
-=back
-
 =head2 F<CISCO-PORT-SECURITY-MIB> globals
 
 =over
