@@ -1,5 +1,4 @@
 # SNMP::Info::CiscoVTP
-# $Id$
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 #
@@ -33,15 +32,16 @@
 package SNMP::Info::CiscoVTP;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::CiscoVTP::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::CiscoVTP::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.81';
 
 %MIBS = (
     'CISCO-VTP-MIB'                       => 'vtpVlanName',
@@ -565,8 +565,6 @@ None.
 
 =back
 
-MIBs can be found at ftp://ftp.cisco.com/pub/mibs/v2/v2.tar.gz
-
 =head1 GLOBALS
 
 =over
