@@ -30,15 +30,16 @@
 package SNMP::Info::Layer3::F5;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 
 @SNMP::Info::Layer3::F5::ISA       = qw/SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::F5::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.81';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -321,11 +322,6 @@ Eric Miller
 
 Abstraction subclass for F5 network devices.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $f5 = new SNMP::Info::Layer3::F5(...);
-
 =head2 Inherited Classes
 
 =over
