@@ -46,7 +46,7 @@ use SNMP::Info::IEEE802dot3ad 'agg_ports_lag';
 
 our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.71';
+$VERSION = '3.81';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -84,14 +84,18 @@ sub vendor {
 
 sub model {
     my $h3c = shift;
+    my $id    = $h3c->id() || '';
+    my $descr = $h3c->description() || '';
+
+    my $entclass = $h3c->entPhysicalClass(2) || {};
+    my $entity   = $entclass->{2} || '';
+    my $entname  = $h3c->entPhysicalName(2)  || {};
 
-    my $descr = $h3c->description();
     if ($descr =~ /^.*\n(.*)\n/) {
         return $1;
-    } elsif ($h3c->entPhysicalClass(2)->{2} =~ /^(3|chassis)$/) {
-        return $h3c->entPhysicalName(2)->{2};
+    } elsif ($entity =~ /^(3|chassis)$/) {
+        return $entname->{2};
     } else {
-        my $id = $h3c->id();
         return &SNMP::translateObj($id) || $id;
     }
 }
@@ -136,6 +140,16 @@ sub i_ignore {
 
 sub agg_ports { return agg_ports_lag(@_) }
 
+# CH: overwrite and always return empty mapping for qb_fdb_index
+# see https://github.com/netdisco/snmp-info/issues/218
+# if no fdb->vlan mapping is available the fdb is assumed to be the vlan
+# which is ok for h3c
+# otherwise h3c will deliver a broken vlan mapping and nodes will jump
+# other all vlans
+sub qb_fdb_index {
+    return {};
+}
+
 1;
 __END__
 
@@ -221,6 +235,11 @@ Returns the OS extracted from C<sysDescr>.
 Returns the software version. Either C<entPhysicalSoftwareRev.2> or extracted from
 C<sysDescr>.
 
+=item $h3c->qb_fdb_index()
+
+overwritten to always return empty hash as implementation on 
+h3c is broken.
+
 =back
 
 =head2 Globals imported from SNMP::Info::Layer3
